@@ -20,7 +20,7 @@
 #       MA 02110-1301, USA.
 
 import gtk, pango, locale, os, webbrowser, re
-import cons, config
+import cons, config, exports
 
 
 def auto_decode_str(in_str, from_clipboard=False):
@@ -53,6 +53,34 @@ def auto_decode_str(in_str, from_clipboard=False):
         out_str = unicode(in_str, cons.STR_UTF8, cons.STR_IGNORE)
     return out_str
 
+def apply_tag_try_link(dad, iter_end, iter_cursor=None):
+    """Try and apply link to previous word (after space or newline)"""
+    iter_start = iter_end.copy()
+    while iter_start.backward_char():
+        curr_char = iter_start.get_char()
+        if curr_char in cons.WEB_LINK_SEPARATORS:
+            iter_start.forward_char()
+            break
+    num_chars = iter_end.get_offset() - iter_start.get_offset()
+    tag_applied = False
+    if num_chars > 4 and get_next_chars_from_iter_are(iter_start, cons.WEB_LINK_STARTERS):
+        dad.curr_buffer.select_range(iter_start, iter_end)
+        link_url = dad.curr_buffer.get_text(iter_start, iter_end)
+        if link_url[0:3] not in ["htt", "ftp"]: link_url = "http://" + link_url
+        property_value = cons.LINK_TYPE_WEBS + cons.CHAR_SPACE + link_url
+        dad.apply_tag(cons.TAG_LINK, property_value=property_value)
+        tag_applied = True
+    elif num_chars > 2 and get_is_camel_case(iter_start, num_chars):
+        node_name = dad.curr_buffer.get_text(iter_start, iter_end)
+        node_dest = dad.get_tree_iter_from_node_name(node_name)
+        if node_dest:
+            dad.curr_buffer.select_range(iter_start, iter_end)
+            property_value = cons.LINK_TYPE_NODE + cons.CHAR_SPACE + str(dad.treestore[node_dest][3])
+            dad.apply_tag(cons.TAG_LINK, property_value=property_value)
+            tag_applied = True
+    if tag_applied and iter_cursor:
+        dad.curr_buffer.place_cursor(iter_cursor)
+
 def apply_tag_try_automatic_bounds(dad, text_buffer=None, iter_start=None):
     """Try to Select a Word Forward/Backward the Cursor"""
     if not text_buffer: text_buffer = dad.curr_buffer
@@ -243,6 +271,10 @@ def on_sourceview_event_after_key_press(dad, text_view, event, syntax_highl):
     elif keyname in [cons.STR_KEY_RETURN, cons.STR_KEY_SPACE]:
         iter_insert = text_buffer.get_iter_at_mark(text_buffer.get_insert())
         if not iter_insert: return False
+        if syntax_highl == cons.RICH_TEXT_ID:
+            iter_end_link = iter_insert.copy()
+            iter_end_link.backward_char()
+            apply_tag_try_link(dad, iter_end_link, iter_insert)
         iter_start = iter_insert.copy()
         if keyname == cons.STR_KEY_RETURN:
             cursor_key_press = iter_insert.get_offset()
@@ -504,6 +536,30 @@ def strip_trailing_spaces(text_buffer):
                 break
     return cleaned_lines
 
+def get_is_camel_case(iter_start, num_chars):
+    """Returns True if the characters compose a camel case word"""
+    text_iter = iter_start.copy()
+    curr_state = 0
+    for i in range(num_chars):
+        curr_char = text_iter.get_char()
+        alphanumeric = re.match('\w', curr_char, re.UNICODE)
+        if not alphanumeric:
+            curr_state = -1
+            break
+        if curr_state == 0:
+            if curr_char.islower():
+                curr_state = 1
+        elif curr_state == 1:
+            if curr_char.isupper():
+                curr_state = 2
+        elif curr_state == 2:
+            if curr_char.islower():
+                curr_state = 3
+        else:
+            pass
+        text_iter.forward_char()
+    return curr_state == 3
+
 def get_next_chars_from_iter_are(iter_start, chars_list):
     """Returns True if one set of the Given Chars are the first after iter"""
     for chars in chars_list:
@@ -742,6 +798,7 @@ _("Czech")+" (cs) Pavel Fric <fripohled@blogspot.com>"+cons.CHAR_NEWLINE+
 _("Dutch")+" (nl) Patrick Vijgeboom <pj.vijgeboom@gmail.com>"+cons.CHAR_NEWLINE+
 _("French")+" (fr) Klaus Becker <colonius@free.fr>"+cons.CHAR_NEWLINE+
 _("German")+" (de) Frank Brungräber <calexu@arcor.de>"+cons.CHAR_NEWLINE+
+_("Greek")+" (el) Delphina <delphina.2009@yahoo.gr>"+cons.CHAR_NEWLINE+
 _("Italian")+" (it) Vincenzo Reale <smart2128@baslug.org>"+cons.CHAR_NEWLINE+
 _("Japanese")+" (ja) Piyo <py2@live.jp>"+cons.CHAR_NEWLINE+
 _("Lithuanian")+" (lt) Zygis <zygimantus@gmail.com>"+cons.CHAR_NEWLINE+
@@ -1475,6 +1532,31 @@ def dialog_selnode_selnodeandsub_alltree(dad, also_selection, also_include_node_
     if response != gtk.RESPONSE_ACCEPT: ret_val = 0
     return ret_val
 
+def dialog_color_pick(dad, curr_color=None):
+    """Dialog to select a color, featuring a palette"""
+    dialog = gtk.ColorSelectionDialog(_("Pick a Color"))
+    dialog.set_transient_for(dad.window)
+    dialog.set_property("modal", True)
+    dialog.set_property("destroy-with-parent", True)
+    dialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
+    gtk_settings = gtk.settings_get_default()
+    gtk_settings.set_property("gtk-color-palette", ":".join(dad.palette_list))
+    colorselection = dialog.get_color_selection()
+    colorselection.set_has_palette(True)
+    if curr_color:
+        colorselection.set_current_color(curr_color)
+    response = dialog.run()
+    dialog.hide()
+    if response != gtk.RESPONSE_OK: return None
+    ret_color = colorselection.get_current_color()
+    color_str_hex8 = "#" + exports.rgb_any_to_24(ret_color.to_string()[1:])
+    if color_str_hex8 in dad.palette_list:
+        dad.palette_list.remove(color_str_hex8)
+    else:
+        dad.palette_list.pop()
+    dad.palette_list.insert(0, color_str_hex8)
+    return ret_color
+
 def set_bookmarks_menu_items(dad):
     """Set Bookmarks Menu Items"""
     bookmarks_menu = dad.ui.get_widget("/MenuBar/BookmarksMenu").get_submenu()
